@@ -11,10 +11,19 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-# $Id: __init__.py 122220 2011-07-14 13:26:32Z janwijbrand $ $Rev$ $Author$ $Date$
+# $Id$ $Rev$ $Author$ $Date$
 """A functional test layer.
 """
-import grokcore.chameleon
-from zope.app.wsgi.testlayer import BrowserLayer
+import zope.app.wsgi.testlayer
+import zope.testbrowser.wsgi
 
-FunctionalLayer = BrowserLayer(grokcore.chameleon, 'ftesting.zcml')
+import grokcore.chameleon
+
+
+class Layer(
+        zope.testbrowser.wsgi.TestBrowserLayer,
+        zope.app.wsgi.testlayer.BrowserLayer):
+    pass
+
+
+FunctionalLayer = Layer(grokcore.chameleon)
